@@ -7,6 +7,8 @@ import re
 ### RegExes for Oracle dialect that Snowflake doesn't support #####
 ###################################################################
 # VARCHAR2(n BYTE) => VARCHAR(n)
+import pandas as pd
+
 varchar2_re = re.compile('(.*)(VARCHAR2\((\d+)(\s+.+)?\))(.*)', re.IGNORECASE)
 
 # CHAR(n BYTE) => CHAR(n)
@@ -17,7 +19,7 @@ char_re = re.compile('(.*)(CHAR\((\d+)(\s+.+)\))(.*)', re.IGNORECASE)
 default_sysdate_re = re.compile('(.*)\ (DEFAULT SYSDATE)\ (.*)', re.IGNORECASE)
 
 # SYSDATE => CURRENT_TIMESTAMP()
-#sysdate_re = re.compile('(.*)\ (SYSDATE)\ (.*)', re.IGNORECASE)
+# sysdate_re = re.compile('(.*)\ (SYSDATE)\ (.*)', re.IGNORECASE)
 sysdate_re = re.compile('(.*[,\(\s])(SYSDATE)([,\)\s].*)', re.IGNORECASE)
 
 # SEGMENT CREATION type => ignore
@@ -113,6 +115,7 @@ set_re = re.compile('(.*)(SET\s+.*TO)(.*)', re.IGNORECASE)
 
 statement_term_re = re.compile('(.*);(.*)', re.IGNORECASE)
 
+
 def make_snow(sqlin, sqlout, no_comments):
     ### processing mode
     comment_lines = None
@@ -143,7 +146,7 @@ def make_snow(sqlin, sqlout, no_comments):
         result = varchar2_re.match(sql)
         if result:
             pre = result.group(1)
-            clause = result.group(2)     # varchar2 clause
+            clause = result.group(2)  # varchar2 clause
             cnt = result.group(3)
             discard = result.group(4)
             post = result.group(5)
@@ -153,7 +156,7 @@ def make_snow(sqlin, sqlout, no_comments):
         result = char_re.match(sql)
         if result:
             pre = result.group(1)
-            clause = result.group(2)     # char clause
+            clause = result.group(2)  # char clause
             cnt = result.group(3)
             discard = result.group(4)
             post = result.group(5)
@@ -192,16 +195,16 @@ def make_snow(sqlin, sqlout, no_comments):
             sql = '{0} TIMESTAMP {1}\t\t-- {2}'.format(pre, post, clause)
 
         # BIGINT => INTEGER
-        #result = bigint_re.match(sql)
-        #if result:
+        # result = bigint_re.match(sql)
+        # if result:
         #    pre = result.group(1)
         #    clause = result.group(2)
         #    post = result.group(3)
         #    sql = '{0} INTEGER {1}\t\t-- {2}'.format(pre, post, clause)
 
         # SMALLINT => INTEGER
-        #result = smallint_re.match(sql)
-        #if result:
+        # result = smallint_re.match(sql)
+        # if result:
         #    pre = result.group(1)
         #    clause = result.group(2)
         #    post = result.group(3)
@@ -290,7 +293,7 @@ def make_snow(sqlin, sqlout, no_comments):
             pre = result.group(1)
             clause = result.group(2)
             post = result.group(3)
-            sql = '{0}CURRENT_TIMESTAMP{1} --{2}'.format(pre,post,clause)
+            sql = '{0}CURRENT_TIMESTAMP{1} --{2}'.format(pre, post, clause)
 
         # bpchar => char
         result = bpchar_re.match(sql)
@@ -298,14 +301,14 @@ def make_snow(sqlin, sqlout, no_comments):
             pre = result.group(1)
             clause = result.group(2)
             post = result.group(3)
-            sql = '{0}char{1} --{2}'.format(pre,post,clause)
+            sql = '{0}char{1} --{2}'.format(pre, post, clause)
 
         result = character_varying_re.match(sql)
         if result:
             pre = result.group(1)
             clause = result.group(2)
             post = result.group(3)
-            sql = '{0}varchar{1}  --{2}'.format(pre,post,clause)
+            sql = '{0}varchar{1}  --{2}'.format(pre, post, clause)
 
         # interleaved => ignore
         result = interleaved_re.match(sql)
@@ -313,14 +316,14 @@ def make_snow(sqlin, sqlout, no_comments):
             pre = result.group(1)
             clause = result.group(2)
             post = result.group(3)
-            sql = '{0} {1} --{2}'.format(pre,post,clause)
+            sql = '{0} {1} --{2}'.format(pre, post, clause)
 
         result = identity_re.match(sql)
         if result:
             pre = result.group(1)
             clause = result.group(2)
             post = result.group(3)
-            sql = '{0} IDENTITY({1},1) {2}'.format(pre,clause,post)
+            sql = '{0} IDENTITY({1},1) {2}'.format(pre, clause, post)
 
         # SEGMENT CREATION type => ignore
         result = segment_creation_re.match(sql)
@@ -423,6 +426,7 @@ def make_snow(sqlin, sqlout, no_comments):
         sf_output.write('\n')
         continue
 
+
 def append_comment(old_comment, new_comment, no_comments):
     if no_comments:
         return None
@@ -432,6 +436,7 @@ def append_comment(old_comment, new_comment, no_comments):
         return new_comment
     return old_comment
 
+
 # ##### MAIN #####
 # if __name__ == "__main__":
 #
@@ -452,7 +457,7 @@ def append_comment(old_comment, new_comment, no_comments):
 
 def convert_to_snowflake_syntax(query, no_comments=False):
     # Open the file in reading mode
-    ifile = open("inputfile.txt", mode = 'w+')
+    ifile = open("inputfile.txt", mode='w+')
     ifile.write(query)
     ifile.close()
 
@@ -467,4 +472,16 @@ def convert_to_snowflake_syntax(query, no_comments=False):
     os.remove("inputfile.txt")
     os.remove("outputfile.txt")
 
-    return sn_query
\ No newline at end of file
+    return sn_query
+
+
+def correct_sql_system_variables_syntax(df, col) -> pd.Series:
+    return df[col]\
+        .str.replace('"year"', "year ") \
+        .str.replace('"level" ', "level ") \
+        .str.replace('"region" ', "region ") \
+        .str.replace('"names" ', "names ") \
+        .str.replace('"type" ', "type ") \
+        .str.replace('"role" ', "role ") \
+        .str.replace('"provider" ', "provider ") \
+        .str.replace('"location" ', "location ")
